' + __("Setup > Profile") + ')',
+ __('Roles can be set for users from their User page.')
+ + ' (' + __("Setup > User") + ')',
'',
'
',
__('The system provides many pre-defined roles. You can add new roles to set finer permissions.')
diff --git a/frappe/core/page/permission_manager/permission_manager.py b/frappe/core/page/permission_manager/permission_manager.py
index 7ad5b1effe..d2f54da872 100644
--- a/frappe/core/page/permission_manager/permission_manager.py
+++ b/frappe/core/page/permission_manager/permission_manager.py
@@ -77,12 +77,12 @@ def clear_doctype_cache(doctype):
@frappe.whitelist()
def get_users_with_role(role):
frappe.only_for("System Manager")
- return [p[0] for p in frappe.db.sql("""select distinct tabProfile.name
- from tabUserRole, tabProfile where
+ return [p[0] for p in frappe.db.sql("""select distinct tabUser.name
+ from tabUserRole, tabUser where
tabUserRole.role=%s
- and tabProfile.name != "Administrator"
- and tabUserRole.parent = tabProfile.name
- and ifnull(tabProfile.enabled,0)=1""", role)]
+ and tabUser.name != "Administrator"
+ and tabUserRole.parent = tabUser.name
+ and ifnull(tabUser.enabled,0)=1""", role)]
@frappe.whitelist()
def get_standard_permissions(doctype):
diff --git a/frappe/core/page/user_properties/user_properties.js b/frappe/core/page/user_properties/user_properties.js
index a7fe659859..ab00811b99 100644
--- a/frappe/core/page/user_properties/user_properties.js
+++ b/frappe/core/page/user_properties/user_properties.js
@@ -160,7 +160,7 @@ frappe.UserProperties = Class.extend({
$.each(this.prop_list, function(i, d) {
var row = $("
{{ profile.first_name or "" }} {{ profile.last_name or "" }}
-
{{ profile.location or "" }}
-
-
\ No newline at end of file
diff --git a/frappe/templates/includes/sitemap_permission.html b/frappe/templates/includes/sitemap_permission.html
index 665b9e9053..4b1fdf3e20 100644
--- a/frappe/templates/includes/sitemap_permission.html
+++ b/frappe/templates/includes/sitemap_permission.html
@@ -1,8 +1,8 @@
-
+
- {% include "templates/includes/profile_display.html" %}
+ {% include "templates/includes/user_display.html" %}
-
-
-
+
+
+
diff --git a/frappe/templates/includes/user_display.html b/frappe/templates/includes/user_display.html
new file mode 100644
index 0000000000..4e6bab9e9d
--- /dev/null
+++ b/frappe/templates/includes/user_display.html
@@ -0,0 +1,9 @@
+
+
+
+
+
+
{{ user.first_name or "" }} {{ user.last_name or "" }}
+
{{ user.location or "" }}
+
+
\ No newline at end of file
diff --git a/frappe/templates/pages/login.py b/frappe/templates/pages/login.py
index 210d8a1a14..b4637d6eeb 100644
--- a/frappe/templates/pages/login.py
+++ b/frappe/templates/pages/login.py
@@ -33,7 +33,7 @@ oauth2_providers = {
"redirect_uri": "/api/method/frappe.templates.pages.login.login_via_google",
"auth_url_data": {
- "scope": "https://www.googleapis.com/auth/userinfo.profile https://www.googleapis.com/auth/userinfo.email",
+ "scope": "https://www.googleapis.com/auth/userinfo.user https://www.googleapis.com/auth/userinfo.email",
"response_type": "code"
},
@@ -162,7 +162,7 @@ def login_via_oauth2(provider, code, decoder=None):
def login_oauth_user(data, provider=None):
user = data["email"]
- if not frappe.db.exists("Profile", user):
+ if not frappe.db.exists("User", user):
create_oauth_user(data, provider)
frappe.local.login_manager.user = user
@@ -183,8 +183,8 @@ def create_oauth_user(data, provider):
if isinstance(data.get("location"), dict):
data["location"] = data.get("location").get("name")
- profile = frappe.bean({
- "doctype":"Profile",
+ user = frappe.bean({
+ "doctype":"User",
"first_name": data.get("first_name") or data.get("given_name") or data.get("name"),
"last_name": data.get("last_name") or data.get("family_name"),
"email": data["email"],
@@ -198,18 +198,18 @@ def create_oauth_user(data, provider):
})
if provider=="facebook":
- profile.doc.fields.update({
+ user.doc.fields.update({
"fb_username": data["username"],
"fb_userid": data["id"],
"user_image": "https://graph.facebook.com/{username}/picture".format(username=data["username"])
})
elif provider=="google":
- profile.doc.google_userid = data["id"]
+ user.doc.google_userid = data["id"]
elif provider=="github":
- profile.doc.github_userid = data["id"]
- profile.doc.github_username = data["login"]
+ user.doc.github_userid = data["id"]
+ user.doc.github_username = data["login"]
- profile.ignore_permissions = True
- profile.get_controller().no_welcome_mail = True
- profile.insert()
+ user.ignore_permissions = True
+ user.get_controller().no_welcome_mail = True
+ user.insert()
diff --git a/frappe/templates/pages/update-password.html b/frappe/templates/pages/update-password.html
index f08173ceb5..dcccd80b86 100644
--- a/frappe/templates/pages/update-password.html
+++ b/frappe/templates/pages/update-password.html
@@ -56,7 +56,7 @@ $(document).ready(function() {
frappe.call({
type: "POST",
- method: "frappe.core.doctype.profile.profile.update_password",
+ method: "frappe.core.doctype.user.user.update_password",
btn: $("#update"),
args: args,
callback: function(r) {
diff --git a/frappe/templates/website_group/forum.py b/frappe/templates/website_group/forum.py
index eab00239a0..70fae3ee97 100644
--- a/frappe/templates/website_group/forum.py
+++ b/frappe/templates/website_group/forum.py
@@ -54,7 +54,7 @@ def get_post_list_html(group, view, limit_start=0, limit_length=20):
posts = frappe.db.sql("""select p.*, pr.user_image, pr.first_name, pr.last_name,
(select count(pc.name) from `tabPost` pc where pc.parent_post=p.name) as post_reply_count
- from `tabPost` p, `tabProfile` pr
+ from `tabPost` p, `tabUser` pr
where p.website_group = %s and pr.name = p.owner and ifnull(p.parent_post, '')=''
{conditions} order by {order_by} limit %s, %s""".format(conditions=conditions, order_by=order_by),
tuple(values), as_dict=True, debug=True)
diff --git a/frappe/templates/website_group/post.py b/frappe/templates/website_group/post.py
index 25e359b64d..1563158975 100644
--- a/frappe/templates/website_group/post.py
+++ b/frappe/templates/website_group/post.py
@@ -26,16 +26,16 @@ def get_post_context(context):
return frappe.cache().get_value(cache_key, lambda: _get_post_context())
def get_parent_post_html(post, context):
- profile = frappe.bean("Profile", post.owner).doc
+ user = frappe.bean("User", post.owner).doc
for fieldname in ("first_name", "last_name", "user_image", "location"):
- post.fields[fieldname] = profile.fields[fieldname]
+ post.fields[fieldname] = user.fields[fieldname]
return frappe.get_template("templates/includes/inline_post.html")\
.render({"post": post.fields, "view": context.view})
def get_child_posts_html(post, context):
posts = frappe.db.sql("""select p.*, pr.user_image, pr.first_name, pr.last_name
- from tabPost p, tabProfile pr
+ from tabPost p, tabUser pr
where p.parent_post=%s and pr.name = p.owner
order by p.creation asc""", (post.name,), as_dict=True)
@@ -139,17 +139,17 @@ def process_picture(post, picture_name, picture):
@frappe.whitelist()
def suggest_user(group, term):
"""suggest a user that has read permission in this group tree"""
- profiles = frappe.db.sql("""select
+ users = frappe.db.sql("""select
pr.name, pr.first_name, pr.last_name,
pr.user_image, pr.location
- from `tabProfile` pr
+ from `tabUser` pr
where (pr.first_name like %(term)s or pr.last_name like %(term)s)
and pr.user_type = 'Website User' and pr.enabled=1""",
{"term": "%{}%".format(term), "group": group}, as_dict=True)
- template = frappe.get_template("templates/includes/profile_display.html")
+ template = frappe.get_template("templates/includes/user_display.html")
return [{
"value": "{} {}".format(pr.first_name or "", pr.last_name or "").strip(),
- "profile_html": template.render({"profile": pr}),
- "profile": pr.name
- } for pr in profiles]
+ "user_html": template.render({"user": pr}),
+ "user": pr.name
+ } for pr in users]
diff --git a/frappe/templates/website_group/settings.html b/frappe/templates/website_group/settings.html
index 32d230875b..646d16cb45 100644
--- a/frappe/templates/website_group/settings.html
+++ b/frappe/templates/website_group/settings.html
@@ -62,7 +62,7 @@
- {% for profile in profiles %}
+ {% for user in users %}
{% include "templates/includes/sitemap_permission.html" %}
{% endfor %}
diff --git a/frappe/templates/website_group/settings.py b/frappe/templates/website_group/settings.py
index 66233297bf..702263ed40 100644
--- a/frappe/templates/website_group/settings.py
+++ b/frappe/templates/website_group/settings.py
@@ -13,25 +13,25 @@ def suggest_user(term, group):
if not get_access(pathname).get("admin"):
raise frappe.PermissionError
- profiles = frappe.db.sql("""select pr.name, pr.first_name, pr.last_name,
+ users = frappe.db.sql("""select pr.name, pr.first_name, pr.last_name,
pr.user_image, pr.location
- from `tabProfile` pr
+ from `tabUser` pr
where (pr.first_name like %(term)s or pr.last_name like %(term)s)
and pr.user_type = "Website User"
and pr.user_image is not null and pr.enabled=1
and not exists(select wsp.name from `tabWebsite Route Permission` wsp
- where wsp.website_route=%(group)s and wsp.profile=pr.name)""",
+ where wsp.website_route=%(group)s and wsp.user=pr.name)""",
{"term": "%{}%".format(term), "group": pathname}, as_dict=True)
- template = frappe.get_template("templates/includes/profile_display.html")
+ template = frappe.get_template("templates/includes/user_display.html")
return [{
"value": "{} {}".format(pr.first_name or "", pr.last_name or ""),
- "profile_html": template.render({"profile": pr}),
- "profile": pr.name
- } for pr in profiles]
+ "user_html": template.render({"user": pr}),
+ "user": pr.name
+ } for pr in users]
@frappe.whitelist()
-def add_sitemap_permission(group, profile):
+def add_sitemap_permission(group, user):
pathname = get_pathname(group)
if not get_access(pathname).get("admin"):
raise frappe.PermissionError
@@ -39,26 +39,26 @@ def add_sitemap_permission(group, profile):
permission = frappe.bean({
"doctype": "Website Route Permission",
"website_route": pathname,
- "profile": profile,
+ "user": user,
"read": 1
})
permission.insert(ignore_permissions=True)
- profile = permission.doc.fields
- profile.update(frappe.db.get_value("Profile", profile.profile,
+ user = permission.doc.fields
+ user.update(frappe.db.get_value("User", user.user,
["name", "first_name", "last_name", "user_image", "location"], as_dict=True))
return frappe.get_template("templates/includes/sitemap_permission.html").render({
- "profile": profile
+ "user": user
})
@frappe.whitelist()
-def update_permission(group, profile, perm, value):
+def update_permission(group, user, perm, value):
pathname = get_pathname(group)
if not get_access(pathname).get("admin"):
raise frappe.PermissionError
- permission = frappe.bean("Website Route Permission", {"website_route": pathname, "profile": profile})
+ permission = frappe.bean("Website Route Permission", {"website_route": pathname, "user": user})
permission.doc.fields[perm] = int(value)
permission.save(ignore_permissions=True)
@@ -68,7 +68,7 @@ def update_permission(group, profile, perm, value):
subject = "You have been made Administrator of Group " + group_title
- send(recipients=[profile],
+ send(recipients=[user],
subject= subject, add_unsubscribe_link=False,
message="""
Group Notification
\
%s
\
diff --git a/frappe/tests/test_db.py b/frappe/tests/test_db.py
index 7802d3273e..8d827accfc 100644
--- a/frappe/tests/test_db.py
+++ b/frappe/tests/test_db.py
@@ -10,21 +10,21 @@ class TestDB(unittest.TestCase):
def test_get_value(self):
from frappe.utils import now_datetime
import time
- frappe.db.sql("""delete from `tabProfile` where name not in ('Administrator', 'Guest')""")
+ frappe.db.sql("""delete from `tabUser` where name not in ('Administrator', 'Guest')""")
now = now_datetime()
- self.assertEquals(frappe.db.get_value("Profile", {"name": ["=", "Administrator"]}), "Administrator")
- self.assertEquals(frappe.db.get_value("Profile", {"name": ["like", "Admin%"]}), "Administrator")
- self.assertEquals(frappe.db.get_value("Profile", {"name": ["!=", "Guest"]}), "Administrator")
- self.assertEquals(frappe.db.get_value("Profile", {"modified": ["<", now]}), "Administrator")
- self.assertEquals(frappe.db.get_value("Profile", {"modified": ["<=", now]}), "Administrator")
+ self.assertEquals(frappe.db.get_value("User", {"name": ["=", "Administrator"]}), "Administrator")
+ self.assertEquals(frappe.db.get_value("User", {"name": ["like", "Admin%"]}), "Administrator")
+ self.assertEquals(frappe.db.get_value("User", {"name": ["!=", "Guest"]}), "Administrator")
+ self.assertEquals(frappe.db.get_value("User", {"modified": ["<", now]}), "Administrator")
+ self.assertEquals(frappe.db.get_value("User", {"modified": ["<=", now]}), "Administrator")
time.sleep(2)
- if "Profile" in frappe.local.test_objects:
- del frappe.local.test_objects["Profile"]
- make_test_records("Profile")
+ if "User" in frappe.local.test_objects:
+ del frappe.local.test_objects["User"]
+ make_test_records("User")
- self.assertEquals("test1@example.com", frappe.db.get_value("Profile", {"modified": [">", now]}))
- self.assertEquals("test1@example.com", frappe.db.get_value("Profile", {"modified": [">=", now]}))
+ self.assertEquals("test1@example.com", frappe.db.get_value("User", {"modified": [">", now]}))
+ self.assertEquals("test1@example.com", frappe.db.get_value("User", {"modified": [">=", now]}))
\ No newline at end of file
diff --git a/frappe/tests/test_email.py b/frappe/tests/test_email.py
index 1c8bae347d..6f875728fe 100644
--- a/frappe/tests/test_email.py
+++ b/frappe/tests/test_email.py
@@ -7,11 +7,11 @@ import os, sys
import unittest, frappe
from frappe.test_runner import make_test_records
-make_test_records("Profile")
+make_test_records("User")
class TestEmail(unittest.TestCase):
def setUp(self):
- frappe.db.sql("""update tabProfile set unsubscribed=0""")
+ frappe.db.sql("""update tabUser set unsubscribed=0""")
frappe.db.sql("""delete from `tabBulk Email`""")
def test_send(self):
@@ -22,7 +22,7 @@ class TestEmail(unittest.TestCase):
from frappe.utils.email_lib.bulk import send
send(recipients = ['test@example.com', 'test1@example.com'],
sender="admin@example.com",
- doctype='Profile', email_field='email',
+ doctype='User', email_field='email',
subject='Testing Bulk', message='This is a bulk mail!')
bulk = frappe.db.sql("""select * from `tabBulk Email` where status='Not Sent'""", as_dict=1)
@@ -44,7 +44,7 @@ class TestEmail(unittest.TestCase):
from frappe.utils.email_lib.bulk import unsubscribe, send
frappe.local.form_dict = {
'email':'test@example.com',
- 'type':'Profile',
+ 'type':'User',
'email_field':'email',
"from_test": True
}
@@ -52,7 +52,7 @@ class TestEmail(unittest.TestCase):
send(recipients = ['test@example.com', 'test1@example.com'],
sender="admin@example.com",
- doctype='Profile', email_field='email',
+ doctype='User', email_field='email',
subject='Testing Bulk', message='This is a bulk mail!')
bulk = frappe.db.sql("""select * from `tabBulk Email` where status='Not Sent'""",
@@ -67,7 +67,7 @@ class TestEmail(unittest.TestCase):
self.assertRaises(BulkLimitCrossedError, send,
recipients=['test@example.com']*1000,
sender="admin@example.com",
- doctype='Profile', email_field='email',
+ doctype='User', email_field='email',
subject='Testing Bulk', message='This is a bulk mail!')
diff --git a/frappe/translate.py b/frappe/translate.py
index 783d20d45c..223bb4c83e 100644
--- a/frappe/translate.py
+++ b/frappe/translate.py
@@ -21,7 +21,7 @@ import frappe, os, re, codecs, json
def get_user_lang(user=None):
if not user:
user = frappe.session.user
- user_lang = frappe.db.get_value("Profile", user, "language")
+ user_lang = frappe.db.get_value("User", user, "language")
return get_lang_dict().get(user_lang!="Loading..." and user_lang or "english")
def get_all_languages():
diff --git a/frappe/translations/ar.csv b/frappe/translations/ar.csv
index 3d51f7a2a8..5999373952 100644
--- a/frappe/translations/ar.csv
+++ b/frappe/translations/ar.csv
@@ -132,7 +132,7 @@ Center,مركز
"Certain documents should not be changed once final, like an Invoice for example. The final state for such documents is called Submitted. You can restrict which roles can Submit.",يجب أن لا يتم تغيير بعض الوثائق النهائية مرة واحدة، مثل الفاتورة على سبيل المثال. ويسمى قدمت الدولة النهائية لهذه الوثائق. يمكنك تقييد الأدوار التي يمكن أن تقدم.
Chat,الدردشة
Check,تحقق
-Check / Uncheck roles assigned to the Profile. Click on the Role to find out what permissions that Role has.,تحقق أدوار ازل / المسندة إلى الملف. انقر على دور لمعرفة ما الأذونات التي الدور الذي.
+Check / Uncheck roles assigned to the User. Click on the Role to find out what permissions that Role has.,تحقق أدوار ازل / المسندة إلى الملف. انقر على دور لمعرفة ما الأذونات التي الدور الذي.
Check this to make this the default letter head in all prints,التحقق من ذلك لجعل هذه الرسالة الافتراضية الرأس في جميع الطبعات
Checked,فحص
Child Tables are shown as a Grid in other DocTypes.,وتظهر جداول الطفل بأنه في الشبكة DocTypes أخرى.
@@ -603,11 +603,11 @@ Print Width,طباعة العرض
Print...,طباعة ...
Priority,أفضلية
Private,خاص
-Profile,الملف الشخصي
-Profile Defaults,الملف الشخصي الافتراضيات
-Profile Represents a User in the system.,الملف الشخصي يمثل مستخدم في النظام.
-Profile of a Blogger,الملف الشخصي من مدون
-Profile of a blog writer.,الملف الشخصي للكاتب بلوق.
+User,الملف الشخصي
+User Defaults,الملف الشخصي الافتراضيات
+User Represents a User in the system.,الملف الشخصي يمثل مستخدم في النظام.
+User of a Blogger,الملف الشخصي من مدون
+User of a blog writer.,الملف الشخصي للكاتب بلوق.
Properties,خصائص
Property,ممتلكات
Property Setter,الملكية واضعة
@@ -815,7 +815,7 @@ To,إلى
"To further restrict permissions based on certain values in a document, use the 'Condition' settings.",لفرض مزيد من القيود أذونات استنادا إلى قيم معينة في وثيقة، استخدم 'حالة' الإعدادات.
To restrict a User of a particular Role to documents that are explicitly assigned to them,لتقييد المستخدم من دور خاص للوثائق التي تم تعيينها بشكل صريح لهم
To restrict a User of a particular Role to documents that are only self-created.,لتقييد المستخدم من دور خاص للوثائق التي ليست سوى الذاتي الإنشاء.
-"To set user roles, just go to Setup > Users and click on the user to assign roles.",لتعيين أدوار المستخدمين، واذهبوا إلى إعداد المستخدمين> وانقر على المستخدم لتعيين الأدوار.
+"To set user roles, just go to Setup > Users and click on the user to assign roles.",لتعيين أدوار المستخدمين، واذهبوا إلى إعداد المستخدمين> وانقر على المستخدم لتعيين الأدوار.
ToDo,قائمة المهام
Tools,أدوات
Top Bar,مقهى الأعلى
@@ -944,7 +944,7 @@ circle-arrow-up,دائرة السهم إلى أعلى
cog,تحكم في
comment,تعليق
comments,تعليقات
-create a Custom Field of type Link (Profile) and then use the 'Condition' settings to map that field to the Permission rule.,إنشاء حقل مخصص من نوع لينك (الملف الشخصي) ثم استخدام 'حالة' إعدادات لتعيين هذا الحقل إلى الحكم إذن.
+create a Custom Field of type Link (User) and then use the 'Condition' settings to map that field to the Permission rule.,إنشاء حقل مخصص من نوع لينك (الملف الشخصي) ثم استخدام 'حالة' إعدادات لتعيين هذا الحقل إلى الحكم إذن.
dd-mm-yyyy,DD-MM-YYYY
dd/mm/yyyy,اليوم / الشهر / السنة
does not exist,غير موجود
diff --git a/frappe/translations/de.csv b/frappe/translations/de.csv
index 31c9e825f1..1d572a49d0 100644
--- a/frappe/translations/de.csv
+++ b/frappe/translations/de.csv
@@ -128,7 +128,7 @@ Center,Zentrum
"Certain documents should not be changed once final, like an Invoice for example. The final state for such documents is called Submitted. You can restrict which roles can Submit.","Bestimmte Dokumente sollten nicht geändert werden, nachdem endgültig angesehen werden, wie eine Rechnung zum Beispiel. Der Endzustand für solche Dokumente wird als Eingereicht b>. Sie können einschränken, welche Rollen können Sie auf Absenden."
Chat,Plaudern
Check,Überprüfen
-Check / Uncheck roles assigned to the Profile. Click on the Role to find out what permissions that Role has.,"Aktivieren / Deaktivieren zugewiesenen Rollen der Profile. Klicken Sie auf die Rolle, um herauszufinden, welche Berechtigungen dieser Rolle hat."
+Check / Uncheck roles assigned to the User. Click on the Role to find out what permissions that Role has.,"Aktivieren / Deaktivieren zugewiesenen Rollen der User. Klicken Sie auf die Rolle, um herauszufinden, welche Berechtigungen dieser Rolle hat."
Check this to make this the default letter head in all prints,"Aktivieren Sie diese Option, um es als Standard-Briefkopf in allen Ausdrucke"
Checked,Geprüft
Child Tables are shown as a Grid in other DocTypes.,Child-Tabellen werden als Grid in anderen DocTypes gezeigt.
@@ -593,11 +593,11 @@ Print Width,Druckbreite
Print...,Drucken ...
Priority,Priorität
Private,Privat
-Profile,Profil
-Profile Defaults,Profil Defaults
-Profile Represents a User in the system.,Stellt ein Benutzerprofil im System.
-Profile of a Blogger,Profil eines Blogger
-Profile of a blog writer.,Profil eines Blog-Schreiber.
+User,Profil
+User Defaults,Profil Defaults
+User Represents a User in the system.,Stellt ein Benutzerprofil im System.
+User of a Blogger,Profil eines Blogger
+User of a blog writer.,Profil eines Blog-Schreiber.
Properties,Eigenschaften
Property,Eigentum
Property Setter,Property Setter
@@ -791,7 +791,7 @@ Title Prefix,Title Prefix
"To report an issue, go to ",
To restrict a User of a particular Role to documents that are explicitly assigned to them,"Um einen Benutzer einer bestimmten Rolle zu Dokumenten, die ihnen ausdrücklich zugeordnet beschränken"
To restrict a User of a particular Role to documents that are only self-created.,"Um einen Benutzer einer bestimmten Rolle zu Dokumenten, die nur selbst erstellte sind zu beschränken."
-"To set user roles, just go to Setup > Users and click on the user to assign roles.","Benutzerrollen, nur um Setup> Benutzer a> und klicken Sie auf den Benutzer Rollen zuweisen."
+"To set user roles, just go to Setup > Users and click on the user to assign roles.","Benutzerrollen, nur um Setup> Benutzer a> und klicken Sie auf den Benutzer Rollen zuweisen."
ToDo,ToDo
Tools,Werkzeuge
Top Bar,Top Bar
@@ -918,7 +918,7 @@ circle-arrow-right,circle-arrow-right
circle-arrow-up,circle-arrow-up
cog,Zahn
comment,Kommentar
-create a Custom Field of type Link (Profile) and then use the 'Condition' settings to map that field to the Permission rule.,"erstellen ein benutzerdefiniertes Feld vom Typ Link (Profile) und dann die 'Bedingung' Einstellungen, um das Feld der Erlaubnis der Regel abzubilden."
+create a Custom Field of type Link (User) and then use the 'Condition' settings to map that field to the Permission rule.,"erstellen ein benutzerdefiniertes Feld vom Typ Link (User) und dann die 'Bedingung' Einstellungen, um das Feld der Erlaubnis der Regel abzubilden."
dd-mm-yyyy,dd-mm-yyyy
dd/mm/yyyy,dd / mm / yyyy
does not exist,nicht vorhanden
diff --git a/frappe/translations/el.csv b/frappe/translations/el.csv
index cfb5d397de..b704763fe5 100644
--- a/frappe/translations/el.csv
+++ b/frappe/translations/el.csv
@@ -132,7 +132,7 @@ Center,Κέντρο
"Certain documents should not be changed once final, like an Invoice for example. The final state for such documents is called Submitted. You can restrict which roles can Submit.","Ορισμένα έγγραφα δεν πρέπει να αλλάζονται μία φορά τελικό, όπως ένα τιμολόγιο για παράδειγμα. Η τελική κατάσταση των εν λόγω εγγράφων ονομάζεται Υποβλήθηκε. Μπορείτε να περιορίσετε το ποιοι ρόλοι θα μπορούν να υποβάλουν."
Chat,Κουβέντα
Check,Έλεγχος
-Check / Uncheck roles assigned to the Profile. Click on the Role to find out what permissions that Role has.,Ελέγξτε / ρόλους Αποεπιλέξτε ανατεθεί στο προφίλ. Κάντε κλικ για το ρόλο για να μάθετε ποια είναι τα δικαιώματα που έχει ο ρόλος.
+Check / Uncheck roles assigned to the User. Click on the Role to find out what permissions that Role has.,Ελέγξτε / ρόλους Αποεπιλέξτε ανατεθεί στο προφίλ. Κάντε κλικ για το ρόλο για να μάθετε ποια είναι τα δικαιώματα που έχει ο ρόλος.
Check this to make this the default letter head in all prints,Επιλέξτε το για να κάνουν αυτό το κεφάλι επιστολή προεπιλογή σε όλες τις εκτυπώσεις
Checked,Δανεισμός
Child Tables are shown as a Grid in other DocTypes.,Οι πίνακες παιδιών απεικονίζεται ως πλέγμα σε άλλες doctypes.
@@ -603,11 +603,11 @@ Print Width,Πλάτος Εκτύπωση
Print...,Εκτύπωση ...
Priority,Προτεραιότητα
Private,Ιδιωτικός
-Profile,Προφίλ
-Profile Defaults,Προεπιλογές Προφίλ
-Profile Represents a User in the system.,Προφίλ Εκπροσωπεί ένα χρήστη στο σύστημα.
-Profile of a Blogger,Προφίλ του Blogger
-Profile of a blog writer.,Προφίλ του blog συγγραφέας.
+User,Προφίλ
+User Defaults,Προεπιλογές Προφίλ
+User Represents a User in the system.,Προφίλ Εκπροσωπεί ένα χρήστη στο σύστημα.
+User of a Blogger,Προφίλ του Blogger
+User of a blog writer.,Προφίλ του blog συγγραφέας.
Properties,Ακίνητα
Property,Ιδιοκτησία
Property Setter,Setter Ακινήτου
@@ -815,7 +815,7 @@ To,Να
"To further restrict permissions based on certain values in a document, use the 'Condition' settings.","Για να περιορίσετε περαιτέρω δικαιώματα βασίζεται σε ορισμένες αξίες σε ένα έγγραφο, χρησιμοποιήστε τα «Κατάσταση» ρυθμίσεις."
To restrict a User of a particular Role to documents that are explicitly assigned to them,Για να περιορίσετε ένα χρήστη από ένα συγκεκριμένο ρόλο σε έγγραφα που έχουν ανατεθεί ρητά σε αυτούς
To restrict a User of a particular Role to documents that are only self-created.,Για να περιορίσετε ένα χρήστη από ένα συγκεκριμένο ρόλο σε έγγραφα που είναι μόνο αυτο-δημιουργήθηκε.
-"To set user roles, just go to Setup > Users and click on the user to assign roles.","Για να ορίσετε τους ρόλους χρήστη, απλά πηγαίνετε να στήσετε χρηστών> και κάντε κλικ στο χρήστη να αναθέσει ρόλους."
+"To set user roles, just go to Setup > Users and click on the user to assign roles.","Για να ορίσετε τους ρόλους χρήστη, απλά πηγαίνετε να στήσετε χρηστών> και κάντε κλικ στο χρήστη να αναθέσει ρόλους."
ToDo,Εκκρεμότητες
Tools,Εργαλεία
Top Bar,Top Bar
@@ -944,7 +944,7 @@ circle-arrow-up,κύκλο-arrow-up
cog,δόντι τροχού
comment,σχόλιο
comments,σχόλια
-create a Custom Field of type Link (Profile) and then use the 'Condition' settings to map that field to the Permission rule.,δημιουργήσετε ένα προσαρμοσμένο πεδίο της σύνδεσης τύπου (Profile) και στη συνέχεια να χρησιμοποιούν τις «Κατάσταση» τις ρυθμίσεις για να χαρτογραφήσει αυτό το πεδίο στον κανόνα άδεια.
+create a Custom Field of type Link (User) and then use the 'Condition' settings to map that field to the Permission rule.,δημιουργήσετε ένα προσαρμοσμένο πεδίο της σύνδεσης τύπου (User) και στη συνέχεια να χρησιμοποιούν τις «Κατάσταση» τις ρυθμίσεις για να χαρτογραφήσει αυτό το πεδίο στον κανόνα άδεια.
dd-mm-yyyy,dd-mm-yyyy
dd/mm/yyyy,ηη / μμ / εεεε
does not exist,δεν υπάρχει
diff --git a/frappe/translations/es.csv b/frappe/translations/es.csv
index 37b561e310..d4dd5570be 100644
--- a/frappe/translations/es.csv
+++ b/frappe/translations/es.csv
@@ -132,7 +132,7 @@ Center,Centro
"Certain documents should not be changed once final, like an Invoice for example. The final state for such documents is called Submitted. You can restrict which roles can Submit.","Algunos documentos no se deben cambiar una vez final, como una factura, por ejemplo. El estado final de dichos documentos se llama Enviado. Puede restringir qué roles pueden Submit."
Chat,Charlar
Check,Comprobar
-Check / Uncheck roles assigned to the Profile. Click on the Role to find out what permissions that Role has.,Compruebe / roles Desmarcar asignado al perfil. Haga clic en la función para averiguar qué permisos que rol tiene.
+Check / Uncheck roles assigned to the User. Click on the Role to find out what permissions that Role has.,Compruebe / roles Desmarcar asignado al perfil. Haga clic en la función para averiguar qué permisos que rol tiene.
Check this to make this the default letter head in all prints,Marca esta casilla para hacer esta cabeza defecto la carta en todas las impresiones
Checked,Comprobado
Child Tables are shown as a Grid in other DocTypes.,Tablas secundarias se muestran como una cuadrícula en DocTypes otros.
@@ -603,11 +603,11 @@ Print Width,Ancho de impresión
Print...,Imprimir ...
Priority,Prioridad
Private,Privado
-Profile,Perfil
-Profile Defaults,Predeterminados del perfil
-Profile Represents a User in the system.,Representa un perfil de usuario en el sistema.
-Profile of a Blogger,Perfil de un Blogger
-Profile of a blog writer.,Perfil de un escritor de blog.
+User,Perfil
+User Defaults,Predeterminados del perfil
+User Represents a User in the system.,Representa un perfil de usuario en el sistema.
+User of a Blogger,Perfil de un Blogger
+User of a blog writer.,Perfil de un escritor de blog.
Properties,Propiedades
Property,Propiedad
Property Setter,Propiedad Setter
@@ -815,7 +815,7 @@ To,A
"To further restrict permissions based on certain values in a document, use the 'Condition' settings.","Para restringir aún más permisos en función de determinados valores en un documento, utilice la "condición" de configuración."
To restrict a User of a particular Role to documents that are explicitly assigned to them,Para restringir un usuario de un papel especial a los documentos que están expresamente asignadas
To restrict a User of a particular Role to documents that are only self-created.,Para restringir un usuario de un rol de particular a documentos que sólo son de creación propia.
-"To set user roles, just go to Setup > Users and click on the user to assign roles.","Para definir funciones de usuario, basta con ir a Configuración> Usuarios y haga clic en el usuario para asignar roles."
+"To set user roles, just go to Setup > Users and click on the user to assign roles.","Para definir funciones de usuario, basta con ir a Configuración> Usuarios y haga clic en el usuario para asignar roles."
ToDo,ToDo
Tools,Instrumentos
Top Bar,Bar Top
@@ -944,7 +944,7 @@ circle-arrow-up,"círculo, flecha hacia arriba"
cog,diente
comment,comentario
comments,comentarios
-create a Custom Field of type Link (Profile) and then use the 'Condition' settings to map that field to the Permission rule.,crear un campo personalizado de enlace tipo (perfil) y luego usar la "condición" configuración para asignar ese campo a la regla de permiso.
+create a Custom Field of type Link (User) and then use the 'Condition' settings to map that field to the Permission rule.,crear un campo personalizado de enlace tipo (perfil) y luego usar la "condición" configuración para asignar ese campo a la regla de permiso.
dd-mm-yyyy,dd-mm-aaaa
dd/mm/yyyy,dd / mm / aaaa
does not exist,no existe
diff --git a/frappe/translations/fr.csv b/frappe/translations/fr.csv
index ad5bf32b8b..f3ea5573ec 100644
--- a/frappe/translations/fr.csv
+++ b/frappe/translations/fr.csv
@@ -132,7 +132,7 @@ Center,Centre
"Certain documents should not be changed once final, like an Invoice for example. The final state for such documents is called Submitted. You can restrict which roles can Submit.","Certains documents ne doivent pas être modifiés une fois définitif, comme une facture par exemple. L'état final de ces documents est appelée Soumis. Vous pouvez restreindre les rôles qui peuvent Soumettre."
Chat,Bavarder
Check,Vérifier
-Check / Uncheck roles assigned to the Profile. Click on the Role to find out what permissions that Role has.,Vérifiez / Décochez les rôles assignés au profil. Cliquez sur le Rôle de savoir ce que ce rôle a des autorisations.
+Check / Uncheck roles assigned to the User. Click on the Role to find out what permissions that Role has.,Vérifiez / Décochez les rôles assignés au profil. Cliquez sur le Rôle de savoir ce que ce rôle a des autorisations.
Check this to make this the default letter head in all prints,Cochez cette case pour faire de cette tête de lettre par défaut dans toutes les copies
Checked,Vérifié
Child Tables are shown as a Grid in other DocTypes.,Tableaux pour enfants sont présentés comme une grille dans DocTypes autres.
@@ -603,11 +603,11 @@ Print Width,Largeur d'impression
Print...,Imprimer ...
Priority,Priorité
Private,Privé
-Profile,Profil
-Profile Defaults,Par défaut le profil
-Profile Represents a User in the system.,Représente un profil utilisateur dans le système.
-Profile of a Blogger,Profil d'un Blogger
-Profile of a blog writer.,Profil d'un auteur de blog.
+User,Profil
+User Defaults,Par défaut le profil
+User Represents a User in the system.,Représente un profil utilisateur dans le système.
+User of a Blogger,Profil d'un Blogger
+User of a blog writer.,Profil d'un auteur de blog.
Properties,Propriétés
Property,Propriété
Property Setter,Setter propriété
@@ -815,7 +815,7 @@ To,À
"To further restrict permissions based on certain values in a document, use the 'Condition' settings.","Afin de restreindre les autorisations sur la base de certaines valeurs dans un document, utilisez la «condition» des paramètres."
To restrict a User of a particular Role to documents that are explicitly assigned to them,Pour limiter un utilisateur d'un rôle particulier aux documents qui sont explicitement affectés à leur
To restrict a User of a particular Role to documents that are only self-created.,Pour limiter un utilisateur d'un rôle particulier aux documents qui ne sont auto-créé.
-"To set user roles, just go to Setup > Users and click on the user to assign roles.","Pour définir les rôles des utilisateurs, allez à Configuration> Utilisateurs et cliquez sur l'utilisateur d'attribuer des rôles."
+"To set user roles, just go to Setup > Users and click on the user to assign roles.","Pour définir les rôles des utilisateurs, allez à Configuration> Utilisateurs et cliquez sur l'utilisateur d'attribuer des rôles."
ToDo,ToDo
Tools,Outils
Top Bar,Top Bar
@@ -944,7 +944,7 @@ circle-arrow-up,cercle-flèche-haut
cog,dent
comment,commenter
comments,commentaires
-create a Custom Field of type Link (Profile) and then use the 'Condition' settings to map that field to the Permission rule.,"créer un champ personnalisé de type de lien (profil), puis utiliser la «condition» des paramètres de cartographier ce domaine à la règle d'autorisation."
+create a Custom Field of type Link (User) and then use the 'Condition' settings to map that field to the Permission rule.,"créer un champ personnalisé de type de lien (profil), puis utiliser la «condition» des paramètres de cartographier ce domaine à la règle d'autorisation."
dd-mm-yyyy,jj-mm-aaaa
dd/mm/yyyy,jj / mm / aaaa
does not exist,n'existe pas
diff --git a/frappe/translations/hi.csv b/frappe/translations/hi.csv
index ea87a6ee8a..b5d59166ca 100644
--- a/frappe/translations/hi.csv
+++ b/frappe/translations/hi.csv
@@ -132,7 +132,7 @@ Center,केंद्र
"Certain documents should not be changed once final, like an Invoice for example. The final state for such documents is called Submitted. You can restrict which roles can Submit.","कुछ दस्तावेजों एक बार अंतिम नहीं उदाहरण के लिए एक चालान की तरह बदल गया है,. ऐसे दस्तावेजों के लिए अंतिम राज्य प्रस्तुत कहा जाता है. आप को सीमित कर सकते हैं जो भूमिका प्रस्तुत कर सकते हैं."
Chat,बातचीत
Check,चेक
-Check / Uncheck roles assigned to the Profile. Click on the Role to find out what permissions that Role has.,/ अनचेक करें प्रोफ़ाइल को सौंपा भूमिकाओं की जाँच करें. रोल पर क्लिक करें पता लगाने के लिए अनुमति है कि क्या भूमिका है.
+Check / Uncheck roles assigned to the User. Click on the Role to find out what permissions that Role has.,/ अनचेक करें प्रोफ़ाइल को सौंपा भूमिकाओं की जाँच करें. रोल पर क्लिक करें पता लगाने के लिए अनुमति है कि क्या भूमिका है.
Check this to make this the default letter head in all prints,इस जाँच के लिए सभी प्रिंट में इस डिफ़ॉल्ट पत्र सिर
Checked,जाँचा गया
Child Tables are shown as a Grid in other DocTypes.,बाल टेबल्स अन्य doctypes में एक ग्रिड के रूप में दिखाया जाता है.
@@ -603,11 +603,11 @@ Print Width,प्रिंट चौड़ाई
Print...,प्रिंट ...
Priority,प्राथमिकता
Private,निजी
-Profile,रूपरेखा
-Profile Defaults,प्रोफ़ाइल डिफ़ॉल्ट्स
-Profile Represents a User in the system.,प्रणाली में एक उपयोगकर्ता का प्रतिनिधित्व करता है.
-Profile of a Blogger,एक ब्लॉगर की प्रोफाइल
-Profile of a blog writer.,एक ब्लॉग लेखक का प्रोफ़ाइल.
+User,रूपरेखा
+User Defaults,प्रोफ़ाइल डिफ़ॉल्ट्स
+User Represents a User in the system.,प्रणाली में एक उपयोगकर्ता का प्रतिनिधित्व करता है.
+User of a Blogger,एक ब्लॉगर की प्रोफाइल
+User of a blog writer.,एक ब्लॉग लेखक का प्रोफ़ाइल.
Properties,गुण
Property,संपत्ति
Property Setter,संपत्ति सेटर
@@ -815,7 +815,7 @@ To,से
"To further restrict permissions based on certain values in a document, use the 'Condition' settings.","आगे एक दस्तावेज़ में कुछ मूल्यों के आधार पर अनुमति को प्रतिबंधित करने के लिए, 'स्थिति' सेटिंग का उपयोग करें."
To restrict a User of a particular Role to documents that are explicitly assigned to them,दस्तावेजों है कि स्पष्ट रूप से उन्हें करने के लिए आवंटित कर रहे हैं एक विशेष भूमिका के एक प्रयोक्ता को प्रतिबंधित
To restrict a User of a particular Role to documents that are only self-created.,दस्तावेजों कि केवल स्वयं बनाया हैं एक विशेष भूमिका के एक प्रयोक्ता को प्रतिबंधित.
-"To set user roles, just go to Setup > Users and click on the user to assign roles.","उपयोगकर्ता भूमिकाओं सेट, बस जाने के सेटअप> उपयोगकर्ता और उपयोगकर्ता पर क्लिक करने के लिए भूमिकाएँ असाइन."
+"To set user roles, just go to Setup > Users and click on the user to assign roles.","उपयोगकर्ता भूमिकाओं सेट, बस जाने के सेटअप> उपयोगकर्ता और उपयोगकर्ता पर क्लिक करने के लिए भूमिकाएँ असाइन."
ToDo,ToDo
Tools,उपकरण
Top Bar,शीर्ष बार
@@ -944,7 +944,7 @@ circle-arrow-up,वृत्त - तीर अप
cog,दांत
comment,टिप्पणी
comments,टिप्पणियां
-create a Custom Field of type Link (Profile) and then use the 'Condition' settings to map that field to the Permission rule.,प्रकार लिंक (प्रोफाइल) के एक कस्टम फ़ील्ड बना सकते हैं और फिर 'स्थिति' सेटिंग का उपयोग करने के लिए अनुमति शासन करने के लिए है कि क्षेत्र के नक्शे.
+create a Custom Field of type Link (User) and then use the 'Condition' settings to map that field to the Permission rule.,प्रकार लिंक (प्रोफाइल) के एक कस्टम फ़ील्ड बना सकते हैं और फिर 'स्थिति' सेटिंग का उपयोग करने के लिए अनुमति शासन करने के लिए है कि क्षेत्र के नक्शे.
dd-mm-yyyy,डीडी-mm-yyyy
dd/mm/yyyy,dd / mm / yyyy
does not exist,मौजूद नहीं है
diff --git a/frappe/translations/hr.csv b/frappe/translations/hr.csv
index a8a8edefa2..532cbf232c 100644
--- a/frappe/translations/hr.csv
+++ b/frappe/translations/hr.csv
@@ -132,7 +132,7 @@ Center,Centar
"Certain documents should not be changed once final, like an Invoice for example. The final state for such documents is called Submitted. You can restrict which roles can Submit.","Određene dokumente ne treba mijenjati jednom finalu, kao i račun za primjer. Konačno stanje za takvim dokumentima se zove Postavio. Možete ograničiti koje uloge mogu Submit."
Chat,Razgovor
Check,Provjeriti
-Check / Uncheck roles assigned to the Profile. Click on the Role to find out what permissions that Role has.,Provjerite / Odznačite uloge dodijeljene profil. Kliknite na ulozi saznati što dozvole da uloga.
+Check / Uncheck roles assigned to the User. Click on the Role to find out what permissions that Role has.,Provjerite / Odznačite uloge dodijeljene profil. Kliknite na ulozi saznati što dozvole da uloga.
Check this to make this the default letter head in all prints,Provjerite to napraviti ovu glavu zadani slovo u svim otisaka
Checked,Provjeren
Child Tables are shown as a Grid in other DocTypes.,Dijete Tablice su prikazane kao Grid u drugim DocTypes.
@@ -603,11 +603,11 @@ Print Width,Širina ispisa
Print...,Ispis ...
Priority,Prioritet
Private,Privatan
-Profile,Profil
-Profile Defaults,Profil Zadano
-Profile Represents a User in the system.,Profil Predstavlja korisnika u sustavu.
-Profile of a Blogger,Profil od Bloggeru
-Profile of a blog writer.,Profil blog pisac.
+User,Profil
+User Defaults,Profil Zadano
+User Represents a User in the system.,Profil Predstavlja korisnika u sustavu.
+User of a Blogger,Profil od Bloggeru
+User of a blog writer.,Profil blog pisac.
Properties,Nekretnine
Property,Vlasništvo
Property Setter,Nekretnine seter
@@ -815,7 +815,7 @@ To,Na
"To further restrict permissions based on certain values in a document, use the 'Condition' settings.","Kako bi se dodatno ograničiti dozvole na temelju određenih vrijednosti u dokumentu, koristite 'stanje' postavke."
To restrict a User of a particular Role to documents that are explicitly assigned to them,Da biste ograničili korisnik određenu ulogu na dokumente koji su izričito dodijeljene im
To restrict a User of a particular Role to documents that are only self-created.,Da biste ograničili korisnik određenu ulogu dokumentima koji su samo self-kreirana.
-"To set user roles, just go to Setup > Users and click on the user to assign roles.","Da biste postavili korisničke uloge, samo idite na Postavke> Korisnici i kliknite na korisnika dodijeliti uloge."
+"To set user roles, just go to Setup > Users and click on the user to assign roles.","Da biste postavili korisničke uloge, samo idite na Postavke> Korisnici i kliknite na korisnika dodijeliti uloge."
ToDo,ToDo
Tools,Alat
Top Bar,Najbolje Bar
@@ -944,7 +944,7 @@ circle-arrow-up,krug sa strelicom prema gore
cog,vršak
comment,komentirati
comments,komentari
-create a Custom Field of type Link (Profile) and then use the 'Condition' settings to map that field to the Permission rule.,"stvoriti Custom Field tipa Link (Profil), a zatim koristiti 'stanje' postavke na karti koje polje na dozvole vladavine."
+create a Custom Field of type Link (User) and then use the 'Condition' settings to map that field to the Permission rule.,"stvoriti Custom Field tipa Link (Profil), a zatim koristiti 'stanje' postavke na karti koje polje na dozvole vladavine."
dd-mm-yyyy,dd-mm-yyyy
dd/mm/yyyy,dd / mm / gggg
does not exist,ne postoji
diff --git a/frappe/translations/it.csv b/frappe/translations/it.csv
index da70959505..4f21d53290 100644
--- a/frappe/translations/it.csv
+++ b/frappe/translations/it.csv
@@ -132,7 +132,7 @@ Center,Centro
"Certain documents should not be changed once final, like an Invoice for example. The final state for such documents is called Submitted. You can restrict which roles can Submit.","Alcuni documenti non devono essere modificati una volta definiti, come una fattura, per esempio. Lo stato finale di tali documenti è chiamato Inserito. È possibile limitare quali ruoli possono Inviare."
Chat,Chat
Check,Seleziona
-Check / Uncheck roles assigned to the Profile. Click on the Role to find out what permissions that Role has.,Seleziona / Deseleziona ruoli assegnati al profilo. Fare clic sul ruolo per scoprire quali autorizzazioni ha il ruolo.
+Check / Uncheck roles assigned to the User. Click on the Role to find out what permissions that Role has.,Seleziona / Deseleziona ruoli assegnati al profilo. Fare clic sul ruolo per scoprire quali autorizzazioni ha il ruolo.
Check this to make this the default letter head in all prints,Seleziona per usare questa intestazione in tutte le stampe
Checked,Selezionato
Child Tables are shown as a Grid in other DocTypes.,Tabelle figlio sono mostrati come una griglia in altre DOCTYPE.
@@ -603,11 +603,11 @@ Print Width,Larghezza di stampa
Print...,Stampa ...
Priority,Priorità
Private,Privato
-Profile,Profilo
-Profile Defaults,Defaults Profilo
-Profile Represents a User in the system.,Profilo Rappresenta un utente nel sistema.
-Profile of a Blogger,Profilo di un Blogger
-Profile of a blog writer.,Profilo di uno scrittore blog.
+User,Profilo
+User Defaults,Defaults Profilo
+User Represents a User in the system.,Profilo Rappresenta un utente nel sistema.
+User of a Blogger,Profilo di un Blogger
+User of a blog writer.,Profilo di uno scrittore blog.
Properties,Proprietà
Property,Proprietà
Property Setter,Setter Proprietà
@@ -815,7 +815,7 @@ To,A
"To further restrict permissions based on certain values in a document, use the 'Condition' settings.","Per limitare ulteriormente i permessi in base a determinati valori di un documento, utilizzare le impostazioni di 'condizione'."
To restrict a User of a particular Role to documents that are explicitly assigned to them,Per impedire a un utente di un particolare ruolo a documenti che sono esplicitamente assegnati a loro
To restrict a User of a particular Role to documents that are only self-created.,Per impedire a un utente di un particolare ruolo a documenti che sono solo auto-creato.
-"To set user roles, just go to Setup > Users and click on the user to assign roles.","Per impostare i ruoli utente, basta andare su Impostazioni> Utenti e fare clic sull'utente per assegnare ruoli."
+"To set user roles, just go to Setup > Users and click on the user to assign roles.","Per impostare i ruoli utente, basta andare su Impostazioni> Utenti e fare clic sull'utente per assegnare ruoli."
ToDo,ToDo
Tools,Strumenti
Top Bar,Top Bar
@@ -944,7 +944,7 @@ circle-arrow-up,cerchio-freccia-up
cog,COG
comment,commento
comments,commenti
-create a Custom Field of type Link (Profile) and then use the 'Condition' settings to map that field to the Permission rule.,Creare un campo personalizzato di tipo Link (profilo) e quindi utilizzare le impostazioni di 'condizione' di mappare il campo per la regola di autorizzazione.
+create a Custom Field of type Link (User) and then use the 'Condition' settings to map that field to the Permission rule.,Creare un campo personalizzato di tipo Link (profilo) e quindi utilizzare le impostazioni di 'condizione' di mappare il campo per la regola di autorizzazione.
dd-mm-yyyy,gg-mm-aaaa
dd/mm/yyyy,gg / mm / aaaa
does not exist,non esiste
diff --git a/frappe/translations/nl.csv b/frappe/translations/nl.csv
index 744bfe8795..26805549cc 100644
--- a/frappe/translations/nl.csv
+++ b/frappe/translations/nl.csv
@@ -132,7 +132,7 @@ Center,Centrum
"Certain documents should not be changed once final, like an Invoice for example. The final state for such documents is called Submitted. You can restrict which roles can Submit.","Bepaalde documenten mogen niet worden gewijzigd zodra de definitieve, zoals een factuur bijvoorbeeld. De eindtoestand van deze documenten wordt genoemd Ingediend. U kunt beperken welke rollen kunnen op Verzenden."
Chat,Praten
Check,Controleren
-Check / Uncheck roles assigned to the Profile. Click on the Role to find out what permissions that Role has.,Controleer / Deselecteer rollen toegewezen aan het profiel. Klik op de rol om uit te vinden welke permissies die taak.
+Check / Uncheck roles assigned to the User. Click on the Role to find out what permissions that Role has.,Controleer / Deselecteer rollen toegewezen aan het profiel. Klik op de rol om uit te vinden welke permissies die taak.
Check this to make this the default letter head in all prints,Vink dit aan om deze de standaard briefpapier maken in alle afdrukken
Checked,Geruit
Child Tables are shown as a Grid in other DocTypes.,Onderliggende tabellen worden weergegeven als een tabel in andere DocTypes.
@@ -603,11 +603,11 @@ Print Width,Printbreedte
Print...,Print ...
Priority,Prioriteit
Private,Prive-
-Profile,Profiel
-Profile Defaults,Profiel Standaardwaarden
-Profile Represents a User in the system.,Profiel Geeft een gebruiker in het systeem.
-Profile of a Blogger,Profiel van een Blogger
-Profile of a blog writer.,Profiel van een blog schrijver.
+User,Profiel
+User Defaults,Profiel Standaardwaarden
+User Represents a User in the system.,Profiel Geeft een gebruiker in het systeem.
+User of a Blogger,Profiel van een Blogger
+User of a blog writer.,Profiel van een blog schrijver.
Properties,Eigenschappen
Property,Eigendom
Property Setter,Onroerend goed Setter
@@ -815,7 +815,7 @@ To,Naar
"To further restrict permissions based on certain values in a document, use the 'Condition' settings.","Om verder te beperken rechten op basis van bepaalde waarden in een document, gebruikt u de 'Staat' instellingen."
To restrict a User of a particular Role to documents that are explicitly assigned to them,Een gebruiker van een bepaalde rol beperken tot documenten die expliciet aan hen toegewezen
To restrict a User of a particular Role to documents that are only self-created.,Om een gebruiker van een bepaalde rol te beperken tot documenten die alleen zelfgeschapen.
-"To set user roles, just go to Setup > Users and click on the user to assign roles.","Om gebruikersrollen in te stellen, ga je gewoon naar > Gebruikers Setup en op de gebruiker Klik om rollen toe te wijzen."
+"To set user roles, just go to Setup > Users and click on the user to assign roles.","Om gebruikersrollen in te stellen, ga je gewoon naar > Gebruikers Setup en op de gebruiker Klik om rollen toe te wijzen."
ToDo,ToDo
Tools,Gereedschap
Top Bar,Top Bar
@@ -944,7 +944,7 @@ circle-arrow-up,cirkel-pijl-up
cog,tand
comment,commentaar
comments,reacties
-create a Custom Field of type Link (Profile) and then use the 'Condition' settings to map that field to the Permission rule.,een aangepast veld van het type Link (Profile) en gebruik dan de 'Staat' instellingen om dat veld toe te wijzen aan de toestemming regel.
+create a Custom Field of type Link (User) and then use the 'Condition' settings to map that field to the Permission rule.,een aangepast veld van het type Link (User) en gebruik dan de 'Staat' instellingen om dat veld toe te wijzen aan de toestemming regel.
dd-mm-yyyy,dd-mm-jjjj
dd/mm/yyyy,dd / mm / yyyy
does not exist,bestaat niet
diff --git a/frappe/translations/pt-BR.csv b/frappe/translations/pt-BR.csv
index aaab865697..d30d5d65bb 100644
--- a/frappe/translations/pt-BR.csv
+++ b/frappe/translations/pt-BR.csv
@@ -132,7 +132,7 @@ Center,Centro
"Certain documents should not be changed once final, like an Invoice for example. The final state for such documents is called Submitted. You can restrict which roles can Submit.","Alguns documentos não devem ser alterados uma vez finalizados, como uma nota fiscal, por exemplo. O estado final de tais documentos é chamado Enviado. Você pode restringir as funções que podem Enviar."
Chat,Conversar
Check,Verificar
-Check / Uncheck roles assigned to the Profile. Click on the Role to find out what permissions that Role has.,Marque / Desmarque funções atribuídas ao perfil. Clique sobre a Função para verificar que permissões a função tem.
+Check / Uncheck roles assigned to the User. Click on the Role to find out what permissions that Role has.,Marque / Desmarque funções atribuídas ao perfil. Clique sobre a Função para verificar que permissões a função tem.
Check this to make this the default letter head in all prints,Marque esta opção para tornar este o cabeçalho padrão em todas as impressões
Checked,Marcado
Child Tables are shown as a Grid in other DocTypes.,Tabelas-filhas são mostradas como uma grade nos outros DocTypes.
@@ -603,11 +603,11 @@ Print Width,Largura de impressão
Print...,Imprimir ...
Priority,Prioridade
Private,Privado
-Profile,Perfil
-Profile Defaults,Padrões de Perfil
-Profile Represents a User in the system.,Perfil representa um usuário no sistema.
-Profile of a Blogger,Perfil de um Blogger
-Profile of a blog writer.,Perfil de um escritor do blog.
+User,Perfil
+User Defaults,Padrões de Perfil
+User Represents a User in the system.,Perfil representa um usuário no sistema.
+User of a Blogger,Perfil de um Blogger
+User of a blog writer.,Perfil de um escritor do blog.
Properties,Propriedades
Property,Propriedade
Property Setter,Setter propriedade
@@ -815,7 +815,7 @@ To,Para
"To further restrict permissions based on certain values in a document, use the 'Condition' settings.","Para restringir ainda mais as permissões com base em determinados valores em um documento, use as definições de 'Condição'."
To restrict a User of a particular Role to documents that are explicitly assigned to them,Para restringir um usuário de uma função a documentos que são explicitamente atribuídos a ele
To restrict a User of a particular Role to documents that are only self-created.,Para restringir um usuário de uma função a apenas documentos que ele próprio criou.
-"To set user roles, just go to Setup > Users and click on the user to assign roles.","Para definir funções ao usuário, basta ir a Configuração> Usuários e clicar sobre o usuário para atribuir funções."
+"To set user roles, just go to Setup > Users and click on the user to assign roles.","Para definir funções ao usuário, basta ir a Configuração> Usuários e clicar sobre o usuário para atribuir funções."
ToDo,Lista de Tarefas
Tools,Ferramentas
Top Bar,Barra Superior
@@ -944,7 +944,7 @@ circle-arrow-up,círculo de seta para cima
cog,roda dentada
comment,comentário
comments,comentários
-create a Custom Field of type Link (Profile) and then use the 'Condition' settings to map that field to the Permission rule.,Criar um Campo Personalizado do tipo ligação (Perfil) e depois usar as configurações de 'Condição' para mapear o campo para a regra de Permissão.
+create a Custom Field of type Link (User) and then use the 'Condition' settings to map that field to the Permission rule.,Criar um Campo Personalizado do tipo ligação (Perfil) e depois usar as configurações de 'Condição' para mapear o campo para a regra de Permissão.
dd-mm-yyyy,dd-mm-aaaa
dd/mm/yyyy,dd/mm/aaaa
does not exist,não existe
diff --git a/frappe/translations/pt.csv b/frappe/translations/pt.csv
index 308f82f61e..74676907a9 100644
--- a/frappe/translations/pt.csv
+++ b/frappe/translations/pt.csv
@@ -132,7 +132,7 @@ Center,Centro
"Certain documents should not be changed once final, like an Invoice for example. The final state for such documents is called Submitted. You can restrict which roles can Submit.","Alguns documentos não deve ser alterado, uma vez final, como uma nota fiscal, por exemplo. O estado final de tais documentos é chamado Enviado. Você pode restringir as funções que podem Enviar."
Chat,Conversar
Check,Verificar
-Check / Uncheck roles assigned to the Profile. Click on the Role to find out what permissions that Role has.,Verifique / Desmarque papéis atribuídos ao perfil. Clique sobre o Papel para descobrir o que as permissões que papel tem.
+Check / Uncheck roles assigned to the User. Click on the Role to find out what permissions that Role has.,Verifique / Desmarque papéis atribuídos ao perfil. Clique sobre o Papel para descobrir o que as permissões que papel tem.
Check this to make this the default letter head in all prints,Marque esta opção para tornar esta a cabeça carta padrão em todas as impressões
Checked,Verificado
Child Tables are shown as a Grid in other DocTypes.,Mesas para crianças são mostrados como uma grade no DOCTYPEs outros.
@@ -603,11 +603,11 @@ Print Width,Largura de impressão
Print...,Imprimir ...
Priority,Prioridade
Private,Privado
-Profile,Perfil
-Profile Defaults,Padrões de Perfil
-Profile Represents a User in the system.,Perfil Representa um usuário no sistema.
-Profile of a Blogger,Perfil de um Blogger
-Profile of a blog writer.,Perfil de um escritor do blog.
+User,Perfil
+User Defaults,Padrões de Perfil
+User Represents a User in the system.,Perfil Representa um usuário no sistema.
+User of a Blogger,Perfil de um Blogger
+User of a blog writer.,Perfil de um escritor do blog.
Properties,Propriedades
Property,Propriedade
Property Setter,Setter propriedade
@@ -815,7 +815,7 @@ To,Para
"To further restrict permissions based on certain values in a document, use the 'Condition' settings.","Para restringir ainda mais permissões com base em determinados valores em um documento, use a 'condição' definições."
To restrict a User of a particular Role to documents that are explicitly assigned to them,Para restringir um usuário de um papel especial a documentos que são explicitamente atribuídos a eles
To restrict a User of a particular Role to documents that are only self-created.,Para restringir um usuário de um papel especial a documentos que são apenas auto-criado.
-"To set user roles, just go to Setup > Users and click on the user to assign roles.","Para definir funções de usuário, basta ir a Configuração> Usuários e clique sobre o usuário para atribuir funções."
+"To set user roles, just go to Setup > Users and click on the user to assign roles.","Para definir funções de usuário, basta ir a Configuração> Usuários e clique sobre o usuário para atribuir funções."
ToDo,ToDo
Tools,Ferramentas
Top Bar,Top Bar
@@ -944,7 +944,7 @@ circle-arrow-up,círculo de seta para cima
cog,roda dentada
comment,comentário
comments,reacties
-create a Custom Field of type Link (Profile) and then use the 'Condition' settings to map that field to the Permission rule.,Criar um campo personalizado de ligação tipo (perfil) e depois usar as configurações de 'condição' para mapear o campo para a regra de permissão.
+create a Custom Field of type Link (User) and then use the 'Condition' settings to map that field to the Permission rule.,Criar um campo personalizado de ligação tipo (perfil) e depois usar as configurações de 'condição' para mapear o campo para a regra de permissão.
dd-mm-yyyy,dd-mm-aaaa
dd/mm/yyyy,dd / mm / aaaa
does not exist,não existe
diff --git a/frappe/translations/sr.csv b/frappe/translations/sr.csv
index a9edc560d2..0262e0e4a3 100644
--- a/frappe/translations/sr.csv
+++ b/frappe/translations/sr.csv
@@ -132,7 +132,7 @@ Center,Центар
"Certain documents should not be changed once final, like an Invoice for example. The final state for such documents is called Submitted. You can restrict which roles can Submit.","Одређене документи не треба мењати једном финалу, као фактура за пример. Коначно стање таквих докумената зове Поднет. Можете да ограничите које улоге могу да поднесу."
Chat,Ћаскање
Check,Проверити
-Check / Uncheck roles assigned to the Profile. Click on the Role to find out what permissions that Role has.,Проверите / поништите улоге додељене профил. Кликните на улогу да сазнате шта дозволе које улога.
+Check / Uncheck roles assigned to the User. Click on the Role to find out what permissions that Role has.,Проверите / поништите улоге додељене профил. Кликните на улогу да сазнате шта дозволе које улога.
Check this to make this the default letter head in all prints,Проверите то да овај главу подразумевану писмо у свим отисцима
Checked,Проверен
Child Tables are shown as a Grid in other DocTypes.,Дете Столови су приказани као Грид у другим ДоцТипес.
@@ -603,11 +603,11 @@ Print Width,Ширина штампе
Print...,Штампа ...
Priority,Приоритет
Private,Приватан
-Profile,Профил
-Profile Defaults,Профил Дефаултс
-Profile Represents a User in the system.,Профил Представља корисника у систему.
-Profile of a Blogger,Профил од Блоггер
-Profile of a blog writer.,Профил од блога писца.
+User,Профил
+User Defaults,Профил Дефаултс
+User Represents a User in the system.,Профил Представља корисника у систему.
+User of a Blogger,Профил од Блоггер
+User of a blog writer.,Профил од блога писца.
Properties,Некретнине
Property,Имовина
Property Setter,Имовина сетер
@@ -815,7 +815,7 @@ To,До
"To further restrict permissions based on certain values in a document, use the 'Condition' settings.","Да би се даље ограничавају дозволе на основу одређених вредности у документу, користите "Стање" подешавања."
To restrict a User of a particular Role to documents that are explicitly assigned to them,Да бисте ограничили корисник посебну улогу у документима који су експлицитно додељене на њих
To restrict a User of a particular Role to documents that are only self-created.,Да бисте ограничили корисник посебну улогу у документима које су само себи створио.
-"To set user roles, just go to Setup > Users and click on the user to assign roles.","Да бисте поставили улоге корисника, само идите на Подешавање корисника> и кликните на корисника да доделите улоге."
+"To set user roles, just go to Setup > Users and click on the user to assign roles.","Да бисте поставили улоге корисника, само идите на Подешавање корисника> и кликните на корисника да доделите улоге."
ToDo,ТоДо
Tools,Алат
Top Bar,Топ Бар
@@ -944,7 +944,7 @@ circle-arrow-up,круг-уп арров
cog,зубац
comment,коментар
comments,Коментари
-create a Custom Field of type Link (Profile) and then use the 'Condition' settings to map that field to the Permission rule.,"креирате Цустом поље типа Линк (профил), а затим користите "Стање" поставке да мапира то поље на Дозвола правила."
+create a Custom Field of type Link (User) and then use the 'Condition' settings to map that field to the Permission rule.,"креирате Цустом поље типа Линк (профил), а затим користите "Стање" поставке да мапира то поље на Дозвола правила."
dd-mm-yyyy,дд-мм-гггг
dd/mm/yyyy,дд / мм / гггг
does not exist,не постоји
diff --git a/frappe/translations/ta.csv b/frappe/translations/ta.csv
index 523d6c1cbd..c15f769f11 100644
--- a/frappe/translations/ta.csv
+++ b/frappe/translations/ta.csv
@@ -132,7 +132,7 @@ Center,மையம்
"Certain documents should not be changed once final, like an Invoice for example. The final state for such documents is called Submitted. You can restrict which roles can Submit.",சில ஆவணங்களை உதாரணமாக ஒரு விலைப்பட்டியல் போன்ற முறை இறுதி மாற்ற கூடாது. அத்தகைய ஆவணங்களை இறுதி மாநில Submitted அழைக்கப்படுகிறது. நீங்கள் நடிக்க சமர்ப்பி இது கட்டுப்படுத்த முடியும்.
Chat,அரட்டை
Check,சோதனை
-Check / Uncheck roles assigned to the Profile. Click on the Role to find out what permissions that Role has.,பதிவு செய்தது ஒதுக்கப்படும் / தேர்வுநீக்கு வேடங்களில் பாருங்கள். பங்கு உண்டு என்று என்ன அனுமதிகள் கண்டுபிடிக்க பங்கு கிளிக்.
+Check / Uncheck roles assigned to the User. Click on the Role to find out what permissions that Role has.,பதிவு செய்தது ஒதுக்கப்படும் / தேர்வுநீக்கு வேடங்களில் பாருங்கள். பங்கு உண்டு என்று என்ன அனுமதிகள் கண்டுபிடிக்க பங்கு கிளிக்.
Check this to make this the default letter head in all prints,அனைத்து அச்சிட்டு இந்த முன்னிருப்பு கடிதம் தலை செய்ய இந்த சோதனை
Checked,சதுர அமைப்பு கொண்டுள்ள
Child Tables are shown as a Grid in other DocTypes.,குழந்தை அட்டவணைகள் மற்ற டாக்டைப்கள் ஒரு கட்டம் காட்டப்படும்.
@@ -603,11 +603,11 @@ Print Width,அச்சு அகலம்
Print...,அச்சு ...
Priority,முதன்மை
Private,தனிப்பட்ட
-Profile,சுயவிவரத்தை
-Profile Defaults,சுயவிவரத்தை இயல்புநிலைகளுக்கு
-Profile Represents a User in the system.,சுயவிவரத்தை கணினியில் ஒரு பயனர் குறிக்கிறது.
-Profile of a Blogger,", ஒரு, பிளாகரின் சுயவிவரத்தை"
-Profile of a blog writer.,ஒரு வலைப்பதிவு எழுத்தாளர் பற்றிய சுயவிவரத்தை.
+User,சுயவிவரத்தை
+User Defaults,சுயவிவரத்தை இயல்புநிலைகளுக்கு
+User Represents a User in the system.,சுயவிவரத்தை கணினியில் ஒரு பயனர் குறிக்கிறது.
+User of a Blogger,", ஒரு, பிளாகரின் சுயவிவரத்தை"
+User of a blog writer.,ஒரு வலைப்பதிவு எழுத்தாளர் பற்றிய சுயவிவரத்தை.
Properties,பண்புகள்
Property,சொத்து
Property Setter,சொத்து செட்டர்
@@ -815,7 +815,7 @@ To,வேண்டும்
"To further restrict permissions based on certain values in a document, use the 'Condition' settings.","மேலும் ஒரு ஆவணத்தில் குறிப்பிட்ட மதிப்புகள் அடிப்படையில் அனுமதிகளை கட்டுப்படுத்த, 'கண்டிஷன்' அமைப்புகளை பயன்படுத்த."
To restrict a User of a particular Role to documents that are explicitly assigned to them,வெளிப்படையாக அவர்களுக்கு ஒதுக்கப்படும் என்று ஆவணங்களை ஒரு குறிப்பிட்ட கதாபாத்திரம் ஒரு பயனர் தடை
To restrict a User of a particular Role to documents that are only self-created.,ஒரே சுய உருவாக்கப்பட்ட என்று ஆவணங்களை ஒரு குறிப்பிட்ட கதாபாத்திரம் ஒரு பயனர் கட்டுப்படுத்துகின்றது.
-"To set user roles, just go to Setup > Users and click on the user to assign roles.","பயனர் பாத்திரங்களை அமைக்க, தான் சென்று > பயனர்கள் அமைக்கவும் மற்றும் பாத்திரங்கள் ஒதுக்க பயனர் கிளிக்."
+"To set user roles, just go to Setup > Users and click on the user to assign roles.","பயனர் பாத்திரங்களை அமைக்க, தான் சென்று > பயனர்கள் அமைக்கவும் மற்றும் பாத்திரங்கள் ஒதுக்க பயனர் கிளிக்."
ToDo,TODO
Tools,கருவிகள்
Top Bar,மேல் பட்டை
@@ -944,7 +944,7 @@ circle-arrow-up,வட்டத்தை-அம்பு அப்
cog,இயந்திர சக்கரத்தின் பல்
comment,கருத்து
comments,கருத்துக்கள்
-create a Custom Field of type Link (Profile) and then use the 'Condition' settings to map that field to the Permission rule.,"வகை இணைப்பு (செய்தது) ஒரு தனிப்பயன் புலம் உருவாக்க, பின்னர் அனுமதி ஆட்சிக்கு என்று துறையில் கண்டறிவதில் 'கண்டிஷன்' அமைப்புகளை பயன்படுத்த."
+create a Custom Field of type Link (User) and then use the 'Condition' settings to map that field to the Permission rule.,"வகை இணைப்பு (செய்தது) ஒரு தனிப்பயன் புலம் உருவாக்க, பின்னர் அனுமதி ஆட்சிக்கு என்று துறையில் கண்டறிவதில் 'கண்டிஷன்' அமைப்புகளை பயன்படுத்த."
dd-mm-yyyy,dd-mm-yyyy
dd/mm/yyyy,dd / mm / yyyy
does not exist,இல்லை
diff --git a/frappe/translations/th.csv b/frappe/translations/th.csv
index b1d94a28ab..defbc221e3 100644
--- a/frappe/translations/th.csv
+++ b/frappe/translations/th.csv
@@ -132,7 +132,7 @@ Center,ศูนย์
"Certain documents should not be changed once final, like an Invoice for example. The final state for such documents is called Submitted. You can restrict which roles can Submit.",เอกสารบางอย่างไม่ควรจะมีการเปลี่ยนแปลงครั้งสุดท้ายเช่นใบแจ้งหนี้สำหรับตัวอย่าง รัฐสุดท้ายสำหรับเอกสารดังกล่าวเรียกว่า Submitted คุณสามารถ จำกัด การซึ่งสามารถส่งบทบาท
Chat,พูดคุย
Check,ตรวจสอบ
-Check / Uncheck roles assigned to the Profile. Click on the Role to find out what permissions that Role has.,ตรวจสอบ / บทบาทที่กำหนดให้ยกเลิกการเลือกรายละเอียด คลิกที่บทบาทเพื่อหาสิ่งที่สิทธิ์บทบาทที่ได้
+Check / Uncheck roles assigned to the User. Click on the Role to find out what permissions that Role has.,ตรวจสอบ / บทบาทที่กำหนดให้ยกเลิกการเลือกรายละเอียด คลิกที่บทบาทเพื่อหาสิ่งที่สิทธิ์บทบาทที่ได้
Check this to make this the default letter head in all prints,ตรวจสอบนี้จะทำให้เรื่องนี้หัวจดหมายเริ่มต้นในการพิมพ์ทั้งหมด
Checked,ถูกตรวจสอบ
Child Tables are shown as a Grid in other DocTypes.,ตารางเด็กจะปรากฏเป็นเส้นตารางใน doctypes อื่น ๆ
@@ -603,11 +603,11 @@ Print Width,ความกว้างพิมพ์
Print...,พิมพ์ ...
Priority,บุริมสิทธิ์
Private,ส่วนตัว
-Profile,รายละเอียด
-Profile Defaults,ค่าดีฟอลต์รายละเอียด
-Profile Represents a User in the system.,รายละเอียดหมายถึงผู้ใช้ในระบบ
-Profile of a Blogger,ดูรายละเอียดของ Blogger
-Profile of a blog writer.,ดูรายละเอียดของนักเขียนบล็อก
+User,รายละเอียด
+User Defaults,ค่าดีฟอลต์รายละเอียด
+User Represents a User in the system.,รายละเอียดหมายถึงผู้ใช้ในระบบ
+User of a Blogger,ดูรายละเอียดของ Blogger
+User of a blog writer.,ดูรายละเอียดของนักเขียนบล็อก
Properties,สรรพคุณ
Property,คุณสมบัติ
Property Setter,สถานที่ให้บริการ Setter
@@ -815,7 +815,7 @@ To,ไปยัง
"To further restrict permissions based on certain values in a document, use the 'Condition' settings.",เพื่อ จำกัด สิทธิ์ตามค่าบางอย่างในเอกสารให้ใช้การตั้งค่า 'สภาพ'
To restrict a User of a particular Role to documents that are explicitly assigned to them,เพื่อ จำกัด ผู้ใช้โดยเฉพาะอย่างยิ่งบทบาทของเอกสารที่ได้รับมอบหมายอย่างชัดเจนเพื่อให้พวกเขา
To restrict a User of a particular Role to documents that are only self-created.,เพื่อ จำกัด ผู้ใช้โดยเฉพาะอย่างยิ่งบทบาทของเอกสารที่มีเฉพาะที่สร้างขึ้นเอง
-"To set user roles, just go to Setup > Users and click on the user to assign roles.",การตั้งบทบาทผู้ใช้เพียงแค่ไปที่ การตั้งค่า> Users และคลิกที่ผู้ใช้สามารถกำหนดบทบาท
+"To set user roles, just go to Setup > Users and click on the user to assign roles.",การตั้งบทบาทผู้ใช้เพียงแค่ไปที่ การตั้งค่า> Users และคลิกที่ผู้ใช้สามารถกำหนดบทบาท
ToDo,สิ่งที่ต้องทำ
Tools,เครื่องมือ
Top Bar,Bar สถานที่ยอด
@@ -944,7 +944,7 @@ circle-arrow-up,วงกลมลูกศรขึ้น
cog,ฟันเฟือง
comment,ความเห็น
comments,ความเห็น
-create a Custom Field of type Link (Profile) and then use the 'Condition' settings to map that field to the Permission rule.,สร้างฟิลด์ที่กำหนดเองของ Link ชนิด (รายละเอียด) แล้วใช้การตั้งค่า 'สภาพ' to map เขตข้อมูลนั้นไปกฎการอนุญาต
+create a Custom Field of type Link (User) and then use the 'Condition' settings to map that field to the Permission rule.,สร้างฟิลด์ที่กำหนดเองของ Link ชนิด (รายละเอียด) แล้วใช้การตั้งค่า 'สภาพ' to map เขตข้อมูลนั้นไปกฎการอนุญาต
dd-mm-yyyy,dd-mm-yyyy
dd/mm/yyyy,วัน / เดือน / ปี
does not exist,ไม่ได้อยู่
diff --git a/frappe/translations/zh-cn.csv b/frappe/translations/zh-cn.csv
index c24f7c6422..06427f5203 100644
--- a/frappe/translations/zh-cn.csv
+++ b/frappe/translations/zh-cn.csv
@@ -132,7 +132,7 @@ Center,中心
"Certain documents should not be changed once final, like an Invoice for example. The final state for such documents is called Submitted. You can restrict which roles can Submit.",某些文件不应该改变最后一次,像发票为例。对这些文件的最后状态被称为提交 。您可以限制哪些角色可以提交。
Chat,聊天
Check,查
-Check / Uncheck roles assigned to the Profile. Click on the Role to find out what permissions that Role has.,查看/取消选中分配给个人的角色。点击角色,找出哪些权限的角色了。
+Check / Uncheck roles assigned to the User. Click on the Role to find out what permissions that Role has.,查看/取消选中分配给个人的角色。点击角色,找出哪些权限的角色了。
Check this to make this the default letter head in all prints,勾选这个来让这个默认的信头中的所有打印
Checked,检查
Child Tables are shown as a Grid in other DocTypes.,子表中显示为其他文档类型的Grid。
@@ -603,11 +603,11 @@ Print Width,打印宽度
Print...,打印...
Priority,优先
Private,私人
-Profile,轮廓
-Profile Defaults,简介默认
-Profile Represents a User in the system.,资料表示系统中的一个用户。
-Profile of a Blogger,是Blogger的个人资料
-Profile of a blog writer.,一个博客作家简介。
+User,轮廓
+User Defaults,简介默认
+User Represents a User in the system.,资料表示系统中的一个用户。
+User of a Blogger,是Blogger的个人资料
+User of a blog writer.,一个博客作家简介。
Properties,属性
Property,属性
Property Setter,属性setter
@@ -815,7 +815,7 @@ To,至
"To further restrict permissions based on certain values in a document, use the 'Condition' settings.",为了进一步限制基于文档中的某些价值观的权限,使用'条件'的设置。
To restrict a User of a particular Role to documents that are explicitly assigned to them,要限制某一特定角色的用户来显式分配给他们的文件
To restrict a User of a particular Role to documents that are only self-created.,要限制某一特定角色的用户到只有自己创建的文档。
-"To set user roles, just go to Setup > Users and click on the user to assign roles.",要设置用户角色,只要进入设置>用户 ,然后单击分配角色的用户。
+"To set user roles, just go to Setup > Users and click on the user to assign roles.",要设置用户角色,只要进入设置>用户 ,然后单击分配角色的用户。
ToDo,待办事项
Tools,工具
Top Bar,顶栏
@@ -944,7 +944,7 @@ circle-arrow-up,圆圈箭头行动
cog,COG
comment,评论
comments,评论
-create a Custom Field of type Link (Profile) and then use the 'Condition' settings to map that field to the Permission rule.,创建类型链接(配置文件)的自定义字段,然后使用“条件”设置到该字段映射到权限规则。
+create a Custom Field of type Link (User) and then use the 'Condition' settings to map that field to the Permission rule.,创建类型链接(配置文件)的自定义字段,然后使用“条件”设置到该字段映射到权限规则。
dd-mm-yyyy,日 - 月 - 年
dd/mm/yyyy,日/月/年
does not exist,不存在
diff --git a/frappe/translations/zh-tw.csv b/frappe/translations/zh-tw.csv
index 0e0bbac61d..508e30619f 100644
--- a/frappe/translations/zh-tw.csv
+++ b/frappe/translations/zh-tw.csv
@@ -132,7 +132,7 @@ Center,中心
"Certain documents should not be changed once final, like an Invoice for example. The final state for such documents is called Submitted. You can restrict which roles can Submit.",某些文件不應該改變最後一次,像發票為例。對這些文件的最後狀態被稱為提交 。您可以限制哪些角色可以提交。
Chat,聊天
Check,查
-Check / Uncheck roles assigned to the Profile. Click on the Role to find out what permissions that Role has.,查看/取消選中分配給個人的角色。點擊角色,找出哪些權限的角色了。
+Check / Uncheck roles assigned to the User. Click on the Role to find out what permissions that Role has.,查看/取消選中分配給個人的角色。點擊角色,找出哪些權限的角色了。
Check this to make this the default letter head in all prints,勾選這個來讓這個默認的信頭中的所有打印
Checked,檢查
Child Tables are shown as a Grid in other DocTypes.,子表中顯示為其他文檔類型的Grid。
@@ -603,11 +603,11 @@ Print Width,打印寬度
Print...,打印...
Priority,優先
Private,私人
-Profile,輪廓
-Profile Defaults,簡介默認
-Profile Represents a User in the system.,資料表示系統中的一個用戶。
-Profile of a Blogger,是Blogger的個人資料
-Profile of a blog writer.,一個博客作家簡介。
+User,輪廓
+User Defaults,簡介默認
+User Represents a User in the system.,資料表示系統中的一個用戶。
+User of a Blogger,是Blogger的個人資料
+User of a blog writer.,一個博客作家簡介。
Properties,屬性
Property,屬性
Property Setter,屬性setter
@@ -815,7 +815,7 @@ To,至
"To further restrict permissions based on certain values in a document, use the 'Condition' settings.",為了進一步限制基於文檔中的某些價值觀的權限,使用'條件'的設置。
To restrict a User of a particular Role to documents that are explicitly assigned to them,要限制某一特定角色的用戶來顯式分配給他們的文件
To restrict a User of a particular Role to documents that are only self-created.,要限制某一特定角色的用戶到只有自己創建的文檔。
-"To set user roles, just go to Setup > Users and click on the user to assign roles.",要設置用戶角色,只要進入設置>用戶 ,然後單擊分配角色的用戶。
+"To set user roles, just go to Setup > Users and click on the user to assign roles.",要設置用戶角色,只要進入設置>用戶 ,然後單擊分配角色的用戶。
ToDo,待辦事項
Tools,工具
Top Bar,頂欄
@@ -944,7 +944,7 @@ circle-arrow-up,圓圈箭頭行動
cog,COG
comment,評論
comments,評論
-create a Custom Field of type Link (Profile) and then use the 'Condition' settings to map that field to the Permission rule.,創建類型鏈接(配置文件)的自定義字段,然後使用“條件”設置到該字段映射到權限規則。
+create a Custom Field of type Link (User) and then use the 'Condition' settings to map that field to the Permission rule.,創建類型鏈接(配置文件)的自定義字段,然後使用“條件”設置到該字段映射到權限規則。
dd-mm-yyyy,日 - 月 - 年
dd/mm/yyyy,日/月/年
does not exist,不存在
diff --git a/frappe/utils/__init__.py b/frappe/utils/__init__.py
index b868ea14b9..b74fd9e1a7 100644
--- a/frappe/utils/__init__.py
+++ b/frappe/utils/__init__.py
@@ -31,20 +31,20 @@ def getCSVelement(v):
return '"'+v+'"'
else: return v or ''
-def get_fullname(profile):
- """get the full name (first name + last name) of the user from Profile"""
+def get_fullname(user):
+ """get the full name (first name + last name) of the user from User"""
if not hasattr(frappe.local, "fullnames"):
frappe.local.fullnames = {}
- if not frappe.local.fullnames.get(profile):
- p = frappe.db.get_value("Profile", profile, ["first_name", "last_name"], as_dict=True)
+ if not frappe.local.fullnames.get(user):
+ p = frappe.db.get_value("User", user, ["first_name", "last_name"], as_dict=True)
if p:
- frappe.local.fullnames[profile] = " ".join(filter(None,
- [p.get('first_name'), p.get('last_name')])) or profile
+ frappe.local.fullnames[user] = " ".join(filter(None,
+ [p.get('first_name'), p.get('last_name')])) or user
else:
- frappe.local.fullnames[profile] = profile
+ frappe.local.fullnames[user] = user
- return frappe.local.fullnames.get(profile)
+ return frappe.local.fullnames.get(user)
def get_formatted_email(user):
"""get email id of user formatted as: John Doe """
diff --git a/frappe/utils/email_lib/__init__.py b/frappe/utils/email_lib/__init__.py
index 58620b09e4..a2831118ce 100644
--- a/frappe/utils/email_lib/__init__.py
+++ b/frappe/utils/email_lib/__init__.py
@@ -39,4 +39,4 @@ def get_system_managers():
WHERE role='System Manager'
AND parent!='Administrator'
AND parent IN
- (SELECT email FROM tabProfile WHERE enabled=1)""")
\ No newline at end of file
+ (SELECT email FROM tabUser WHERE enabled=1)""")
\ No newline at end of file
diff --git a/frappe/utils/email_lib/bulk.py b/frappe/utils/email_lib/bulk.py
index 110e03dcab..ffdd6e2094 100644
--- a/frappe/utils/email_lib/bulk.py
+++ b/frappe/utils/email_lib/bulk.py
@@ -13,7 +13,7 @@ from frappe.utils import cint, get_url, nowdate
class BulkLimitCrossedError(frappe.ValidationError): pass
-def send(recipients=None, sender=None, doctype='Profile', email_field='email',
+def send(recipients=None, sender=None, doctype='User', email_field='email',
subject='[No Subject]', message='[No Content]', ref_doctype=None, ref_docname=None,
add_unsubscribe_link=True):
def is_unsubscribed(rdata):
diff --git a/frappe/utils/install.py b/frappe/utils/install.py
index 14e1f078b9..96c70bbffc 100644
--- a/frappe/utils/install.py
+++ b/frappe/utils/install.py
@@ -16,14 +16,14 @@ def after_install():
# core users / roles
install_docs = [
- {'doctype':'Profile', 'name':'Administrator', 'first_name':'Administrator',
+ {'doctype':'User', 'name':'Administrator', 'first_name':'Administrator',
'email':'admin@localhost', 'enabled':1},
- {'doctype':'Profile', 'name':'Guest', 'first_name':'Guest',
+ {'doctype':'User', 'name':'Guest', 'first_name':'Guest',
'email':'guest@localhost', 'enabled':1},
{'doctype':'UserRole', 'parent': 'Administrator', 'role': 'Administrator',
- 'parenttype':'Profile', 'parentfield':'user_roles'},
+ 'parenttype':'User', 'parentfield':'user_roles'},
{'doctype':'UserRole', 'parent': 'Guest', 'role': 'Guest',
- 'parenttype':'Profile', 'parentfield':'user_roles'},
+ 'parenttype':'User', 'parentfield':'user_roles'},
{'doctype': "Role", "role_name": "Report Manager"}
]
@@ -34,7 +34,7 @@ def after_install():
pass
# all roles to admin
- frappe.bean("Profile", "Administrator").get_controller().add_roles(*frappe.db.sql_list("""
+ frappe.bean("User", "Administrator").get_controller().add_roles(*frappe.db.sql_list("""
select name from tabRole"""))
# update admin password
diff --git a/frappe/website/doctype/blog_post/test_blog_post.py b/frappe/website/doctype/blog_post/test_blog_post.py
index 167345dfc4..58f878e7c6 100644
--- a/frappe/website/doctype/blog_post/test_blog_post.py
+++ b/frappe/website/doctype/blog_post/test_blog_post.py
@@ -29,7 +29,7 @@ import unittest
from frappe.core.page.user_properties.user_properties import add, remove, get_properties, clear_restrictions
-test_dependencies = ["Profile"]
+test_dependencies = ["User"]
class TestBlogPost(unittest.TestCase):
def setUp(self):
frappe.db.sql("""update tabDocPerm set `restricted`=0 where parent='Blog Post'
@@ -39,11 +39,11 @@ class TestBlogPost(unittest.TestCase):
frappe.clear_cache(doctype="Blog Post")
- profile = frappe.bean("Profile", "test1@example.com")
- profile.get_controller().add_roles("Website Manager")
+ user = frappe.bean("User", "test1@example.com")
+ user.get_controller().add_roles("Website Manager")
- profile = frappe.bean("Profile", "test2@example.com")
- profile.get_controller().add_roles("Blogger")
+ user = frappe.bean("User", "test2@example.com")
+ user.get_controller().add_roles("Blogger")
frappe.set_user("test1@example.com")
diff --git a/frappe/website/doctype/blogger/README.md b/frappe/website/doctype/blogger/README.md
index 13ddecda70..994e686ad2 100644
--- a/frappe/website/doctype/blogger/README.md
+++ b/frappe/website/doctype/blogger/README.md
@@ -1 +1 @@
-Profile of blog writer in "Blog" section.
\ No newline at end of file
+User of blog writer in "Blog" section.
\ No newline at end of file
diff --git a/frappe/website/doctype/blogger/blogger.py b/frappe/website/doctype/blogger/blogger.py
index 3b7197cf4b..3b71838336 100644
--- a/frappe/website/doctype/blogger/blogger.py
+++ b/frappe/website/doctype/blogger/blogger.py
@@ -12,14 +12,14 @@ class DocType:
self.doc, self.doclist = d, dl
def on_update(self):
- "if profile is set, then update all older blogs"
+ "if user is set, then update all older blogs"
from frappe.website.doctype.blog_post.blog_post import clear_blog_cache
clear_blog_cache()
- if self.doc.profile:
+ if self.doc.user:
for blog in frappe.db.sql_list("""select name from `tabBlog Post` where owner=%s
- and ifnull(blogger,'')=''""", self.doc.profile):
+ and ifnull(blogger,'')=''""", self.doc.user):
b = frappe.bean("Blog Post", blog)
b.doc.blogger = self.doc.name
b.save()
\ No newline at end of file
diff --git a/frappe/website/doctype/blogger/blogger.txt b/frappe/website/doctype/blogger/blogger.txt
index c093e8d4d1..3d7f343ea2 100644
--- a/frappe/website/doctype/blogger/blogger.txt
+++ b/frappe/website/doctype/blogger/blogger.txt
@@ -2,7 +2,7 @@
{
"creation": "2013-03-25 16:00:51",
"docstatus": 0,
- "modified": "2013-12-20 19:23:57",
+ "modified": "2013-12-20 19:23:58",
"modified_by": "Administrator",
"owner": "Administrator"
},
@@ -10,7 +10,7 @@
"allow_attach": 1,
"allow_import": 1,
"autoname": "field:short_name",
- "description": "Profile of a Blogger",
+ "description": "User ID of a Blogger",
"doctype": "DocType",
"document_type": "Master",
"icon": "icon-user",
@@ -66,10 +66,10 @@
},
{
"doctype": "DocField",
- "fieldname": "profile",
+ "fieldname": "user",
"fieldtype": "Link",
- "label": "Profile",
- "options": "Profile"
+ "label": "User",
+ "options": "User"
},
{
"doctype": "DocField",
diff --git a/frappe/website/doctype/post/post.txt b/frappe/website/doctype/post/post.txt
index 75f2ac4cd3..a9970af463 100644
--- a/frappe/website/doctype/post/post.txt
+++ b/frappe/website/doctype/post/post.txt
@@ -2,7 +2,7 @@
{
"creation": "2014-01-07 14:00:04",
"docstatus": 0,
- "modified": "2014-03-03 14:53:18",
+ "modified": "2014-03-03 14:53:19",
"modified_by": "Administrator",
"owner": "Administrator"
},
@@ -96,7 +96,7 @@
"fieldname": "assigned_to",
"fieldtype": "Link",
"label": "Assigned To",
- "options": "Profile"
+ "options": "User"
},
{
"doctype": "DocField",
diff --git a/frappe/website/doctype/website_route_permission/website_route_permission.py b/frappe/website/doctype/website_route_permission/website_route_permission.py
index f3aaad70b0..3a840cd7df 100644
--- a/frappe/website/doctype/website_route_permission/website_route_permission.py
+++ b/frappe/website/doctype/website_route_permission/website_route_permission.py
@@ -12,5 +12,5 @@ class DocType:
def on_update(self):
remove_empty_permissions()
- clear_permissions(self.doc.profile)
+ clear_permissions(self.doc.user)
\ No newline at end of file
diff --git a/frappe/website/doctype/website_route_permission/website_route_permission.txt b/frappe/website/doctype/website_route_permission/website_route_permission.txt
index 9297fae96d..ee5e3390b7 100644
--- a/frappe/website/doctype/website_route_permission/website_route_permission.txt
+++ b/frappe/website/doctype/website_route_permission/website_route_permission.txt
@@ -2,7 +2,7 @@
{
"creation": "2014-01-29 17:56:29",
"docstatus": 0,
- "modified": "2014-02-24 13:17:17",
+ "modified": "2014-02-24 13:17:18",
"modified_by": "Administrator",
"owner": "Administrator"
},
@@ -54,10 +54,10 @@
},
{
"doctype": "DocField",
- "fieldname": "profile",
+ "fieldname": "user",
"fieldtype": "Link",
- "label": "Profile",
- "options": "Profile",
+ "label": "User",
+ "options": "User",
"reqd": 1,
"search_index": 1
},
diff --git a/frappe/website/doctype/website_sitemap_permission/website_sitemap_permission.py b/frappe/website/doctype/website_sitemap_permission/website_sitemap_permission.py
deleted file mode 100644
index 8f77cdfbb7..0000000000
--- a/frappe/website/doctype/website_sitemap_permission/website_sitemap_permission.py
+++ /dev/null
@@ -1,16 +0,0 @@
-# Copyright (c) 2013, Web Notes Technologies Pvt. Ltd. and Contributors
-# MIT License. See license.txt
-
-from __future__ import unicode_literals
-import frappe
-
-from frappe.website.permissions import remove_empty_permissions, clear_permissions
-
-class DocType:
- def __init__(self, d, dl):
- self.doc, self.doclist = d, dl
-
- def on_update(self):
- remove_empty_permissions()
- clear_permissions(self.doc.profile)
-
diff --git a/frappe/website/doctype/website_sitemap_permission/website_sitemap_permission.txt b/frappe/website/doctype/website_sitemap_permission/website_sitemap_permission.txt
deleted file mode 100644
index 55a86f5826..0000000000
--- a/frappe/website/doctype/website_sitemap_permission/website_sitemap_permission.txt
+++ /dev/null
@@ -1,84 +0,0 @@
-[
- {
- "creation": "2014-01-29 17:56:29",
- "docstatus": 0,
- "modified": "2014-02-11 19:26:33",
- "modified_by": "Administrator",
- "owner": "Administrator"
- },
- {
- "autoname": "WSP.######",
- "doctype": "DocType",
- "icon": "icon-shield",
- "module": "Website",
- "name": "__common__"
- },
- {
- "doctype": "DocField",
- "in_list_view": 1,
- "name": "__common__",
- "parent": "Website Route Permission",
- "parentfield": "fields",
- "parenttype": "DocType",
- "permlevel": 0
- },
- {
- "create": 1,
- "delete": 1,
- "doctype": "DocPerm",
- "export": 1,
- "import": 0,
- "name": "__common__",
- "parent": "Website Route Permission",
- "parentfield": "permissions",
- "parenttype": "DocType",
- "permlevel": 0,
- "read": 1,
- "report": 1,
- "role": "Website Manager",
- "write": 1
- },
- {
- "doctype": "DocType",
- "name": "Website Route Permission"
- },
- {
- "doctype": "DocField",
- "fieldname": "website_route",
- "fieldtype": "Link",
- "label": "Website Route",
- "options": "Website Route",
- "reqd": 1,
- "search_index": 1
- },
- {
- "doctype": "DocField",
- "fieldname": "profile",
- "fieldtype": "Link",
- "label": "Profile",
- "options": "Profile",
- "reqd": 1,
- "search_index": 1
- },
- {
- "doctype": "DocField",
- "fieldname": "read",
- "fieldtype": "Check",
- "label": "Read"
- },
- {
- "doctype": "DocField",
- "fieldname": "write",
- "fieldtype": "Check",
- "label": "Write"
- },
- {
- "doctype": "DocField",
- "fieldname": "admin",
- "fieldtype": "Check",
- "label": "Admin"
- },
- {
- "doctype": "DocPerm"
- }
-]
\ No newline at end of file
diff --git a/frappe/website/js/website_group.js b/frappe/website/js/website_group.js
index 0505b2e697..f42ad93ebb 100644
--- a/frappe/website/js/website_group.js
+++ b/frappe/website/js/website_group.js
@@ -166,7 +166,7 @@ $.extend(website, {
close.on("click", function() {
// clear assignment
$post_editor.find(".assigned-to").addClass("hide");
- $post_editor.find(".assigned-profile").html("");
+ $post_editor.find(".assigned-user").html("");
$post_editor.find('[data-fieldname="assigned_to"]').val(null);
$control_assign.val(null);
});
@@ -178,7 +178,7 @@ $.extend(website, {
$control: $control_assign,
select: function(value, item) {
var $assigned_to = $post_editor.find(".assigned-to").removeClass("hide");
- $assigned_to.find(".assigned-profile").html(item.profile_html);
+ $assigned_to.find(".assigned-user").html(item.user_html);
$post_editor.find('[data-fieldname="assigned_to"]').val(value);
bind_close();
},
@@ -358,12 +358,12 @@ $.extend(website, {
},
select: function(event, ui) {
opts.$control.val("");
- opts.select(ui.item.profile, ui.item);
+ opts.select(ui.item.user, ui.item);
}
});
$user_suggest.data( "ui-autocomplete" )._renderItem = function(ul, item) {
- return $("
diff --git a/frappe/profile.py b/frappe/utils/user.py
similarity index 90%
rename from frappe/profile.py
rename to frappe/utils/user.py
index f31e656e0d..32e85b8cae 100644
--- a/frappe/profile.py
+++ b/frappe/utils/user.py
@@ -5,10 +5,10 @@ from __future__ import unicode_literals
import frappe, json
-class Profile:
+class User:
"""
- A profile object is created at the beginning of every request with details of the use.
- The global profile object is `frappe.user`
+ A user object is created at the beginning of every request with details of the use.
+ The global user object is `frappe.user`
"""
def __init__(self, name=''):
self.defaults = None
@@ -149,10 +149,10 @@ class Profile:
self.build_permissions()
return self.can_read
- def load_profile(self):
+ def load_user(self):
d = frappe.db.sql("""select email, first_name, last_name,
email_signature, background_image, user_type, language
- from tabProfile where name = %s""", (self.name,), as_dict=1)[0]
+ from tabUser where name = %s""", (self.name,), as_dict=1)[0]
if not self.can_read:
self.build_permissions()
@@ -173,15 +173,15 @@ class Profile:
return d
def get_user_fullname(user):
- fullname = frappe.db.sql("SELECT CONCAT_WS(' ', first_name, last_name) FROM `tabProfile` WHERE name=%s", (user,))
+ fullname = frappe.db.sql("SELECT CONCAT_WS(' ', first_name, last_name) FROM `tabUser` WHERE name=%s", (user,))
return fullname and fullname[0][0] or ''
def get_system_managers(only_name=False):
- """returns all system manager's profile details"""
+ """returns all system manager's user details"""
import email.utils
system_managers = frappe.db.sql("""select distinct name,
concat_ws(" ", if(first_name="", null, first_name), if(last_name="", null, last_name))
as fullname from tabProfile p
where docstatus < 2 and enabled = 1
and name not in ("Administrator", "Guest")
and exists (select * from tabUserRole ur
@@ -192,13 +192,13 @@ def get_system_managers(only_name=False):
else:
return [email.utils.formataddr((p.fullname, p.name)) for p in system_managers]
-def add_role(profile, role):
- profile_wrapper = frappe.bean("Profile", profile).get_controller().add_roles(role)
+def add_role(user, role):
+ user_wrapper = frappe.bean("User", user).get_controller().add_roles(role)
def add_system_manager(email, first_name=None, last_name=None):
- # add profile
- profile = frappe.new_bean("Profile")
- profile.doc.fields.update({
+ # add user
+ user = frappe.new_bean("User")
+ user.doc.fields.update({
"name": email,
"email": email,
"enabled": 1,
@@ -206,12 +206,12 @@ def add_system_manager(email, first_name=None, last_name=None):
"last_name": last_name,
"user_type": "System User"
})
- profile.insert()
+ user.insert()
# add roles
roles = frappe.db.sql_list("""select name from `tabRole`
where name not in ("Administrator", "Guest", "All")""")
- profile.get_controller().add_roles(*roles)
+ user.get_controller().add_roles(*roles)
def get_roles(username=None, with_standard=True):
"""get roles of current user"""
@@ -173,15 +173,15 @@ class Profile:
system_managers = frappe.db.sql("""select distinct name,
concat_ws(" ", if(first_name="", null, first_name), if(last_name="", null, last_name))
- as fullname from tabProfile p
+ as fullname from tabUser p
where docstatus < 2 and enabled = 1
and name not in ("Administrator", "Guest")